==> orchestra-api-4.3.0-sources.jar: org/ow2/orchestra/facade/data/runtime/ScopeUpdateData.java <==
/**
 * Copyright (C) 2008 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.data.runtime;

import org.ow2.orchestra.facade.data.AbstractData;
import org.ow2.orchestra.facade.uuid.ActivityInstanceUUID;

/**
 *
 * @author Gael Lalire
 */
public abstract class ScopeUpdateData extends AbstractData {

  private final ActivityInstanceUUID scopeActivityUUID;

  private final ActivityInstanceUUID activityUUID;

  public ScopeUpdateData(final ActivityInstanceUUID scopeActivityUUID, final ActivityInstanceUUID activityUUID) {
    this.scopeActivityUUID = scopeActivityUUID;
    this.activityUUID = activityUUID;
  }

  /**
   * @return the scopeActivityUUID
   */
  public ActivityInstanceUUID getScopeActivityUUID() {
    return this.scopeActivityUUID;
  }

  /**
   * @return the activityUUID which update scope
   */
  public ActivityInstanceUUID getActivityUUID() {
    return this.activityUUID;
  }

}

==> orchestra-api-4.9.1-sources.jar: org/ow2/orchestra/facade/data/runtime/ScopeUpdateData.java <==
/**
 * Copyright (C) 2008 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.data.runtime;

import org.ow2.orchestra.facade.data.AbstractData;
import org.ow2.orchestra.facade.uuid.ActivityInstanceUUID;

/**
 *
 * @author Gael Lalire
 */
public abstract class ScopeUpdateData extends AbstractData {

  private static final long serialVersionUID = -1475069998606097027L;

  private final ActivityInstanceUUID scopeActivityUUID;

  private final ActivityInstanceData activityData;

  public ScopeUpdateData(final ActivityInstanceUUID scopeActivityUUID, final ActivityInstanceData activityData) {
    this.scopeActivityUUID = scopeActivityUUID;
    this.activityData = activityData;
  }

  /**
   * @return the scopeActivityUUID
   */
  public ActivityInstanceUUID getScopeActivityUUID() {
    return this.scopeActivityUUID;
  }

  /**
   * @return the activityUUID which update scope
   */
  public ActivityInstanceUUID getActivityUUID() {
    return this.activityData.getUUID();
  }


  /**
   * @return the activityData
   */
  public ActivityInstanceData getActivityData() {
    return this.activityData;
  }

}
